@@ -129,7 +129,7 @@ class ExprMeta(type):
                 # set the root element when the chained expr begins to find.
                 # the partial exprs of the nested expr
                 # can execute find method many times
-                # but only the first times finding can set the root element.
+                # but only the first time finding can set the root element.
                 token_root = var_root.set(element)
 
             token_finding = var_finding.set(True)
@@ -198,10 +198,7 @@ class Expr(metaclass=ExprMeta):
             else:
                 parts.append(part)
 
-            if expr.ref_right:
-                expr = expr.ref_right()
-            else:
-                expr = None
+            expr = expr.get_next()
 
         return ".".join(parts)
 
